library(repeated)
library(gnlm)

deaths <- scan("deaths.dat",skip=3)
y <- restovec(matrix(deaths,ncol=72,byrow=T))
sex <- c(0,1)
seasc <- rep(cos(pi*rep(1:12,6)/6),2)
seass <- rep(sin(pi*rep(1:12,6)/6),2)
seasc2 <- rep(cos(pi*rep(1:12,6)/3),2)
seass2 <- rep(sin(pi*rep(1:12,6)/3),2)
seasc3 <- rep(cos(2*pi*rep(1:12,6)/3),2)
seass3 <- rep(sin(2*pi*rep(1:12,6)/3),2)
tvc3t <- list(cbind(cos(pi*rep(1:12,6)/6),sin(pi*rep(1:12,6)/6),
	cos(pi*rep(1:12,6)/3),sin(pi*rep(1:12,6)/3),
	cos(2*pi*rep(1:12,6)/3),sin(2*pi*rep(1:12,6)/3)),
	cbind(cos(pi*rep(1:12,6)/6),sin(pi*rep(1:12,6)/6),
	cos(pi*rep(1:12,6)/3),sin(pi*rep(1:12,6)/3),
	cos(2*pi*rep(1:12,6)/3),sin(2*pi*rep(1:12,6)/3)))
reps <- rmna(y,ccov=tcctomat(sex),tvc=tvctomat(tvc3t,
	names=c("cos6","sin6","cos3","sin3","cos1.5","sin1.5")))

sum(deaths-deaths*log(deaths)+lgamma(deaths+1))+144
print(z0 <- glm(deaths~1,family=poisson))
z0$aic/2
print(z1 <- update(z0,.~.+gl(2,72,144)))
z1$aic/2
print(z2 <- update(z1,.~.+seasc+seass))
z2$aic/2
print(z3 <- update(z2,.~.+seasc2+seass2))
z3$aic/2
print(z4 <- update(z3,.~.+seasc3+seass3))
z4$aic/2
print(z5 <- update(z4,.~.+rep(1:72,2)))
z5$aic/2

mu <- function(p,linear) exp(linear)
gnlr(reps,"negative bin",mu=~1,pmu=1000,psh=-1)
gnlr(reps,"negative bin",mu=mu,linear=~sex,pmu=c(7.3,-1),psh=-1)
gnlr(reps,"negative bin",mu=mu,linear=~sex+sin6+cos6,
	pmu=c(7.3,-1,0.2,0.3),psh=-1)
gnlr(reps,"negative bin",mu=mu,linear=~sex+sin6+cos6
	+sin3+cos3,pmu=c(7.3,-1,0.3,0.2,0,0),psh=-1)
gnlr(reps,"negative bin",mu=mu,linear=~sex+sin6+cos6
	+sin3+cos3+sin1.5+cos1.5,pmu=c(7.3,-1,0.3,0.2,0.06,0,0,0),psh=-1)
gnlr(reps,"negative bin",mu=mu,linear=~sex+sin6+cos6
	+sin3+cos3+sin1.5+cos1.5+times,
	pmu=c(7.3,-1,0.3,0.2,0.06,0,0,0,0),psh=-1)

# same models using kalcount
kalcount(reps,preg=-7)
kalcount(reps,preg=-c(7,-1.1),ccov=~sex,pinit=0.1)
kalcount(reps,preg=-c(7.3,-1),ccov=~sex,pinit=0.01,tvc=~cos6+sin6,
	ptvc=-c(0.2,0.3))
kalcount(reps,preg=-c(7.3,-1),ccov=~sex,pinit=0.01,
	tvc=~cos6+sin6+cos3+sin3,ptvc=-c(0.2,0.3,0.006,0.05))
kalcount(reps,preg=-c(7.3,-1),ccov=~sex,pinit=0.01,
	tvc=~cos6+sin6+cos3+sin3+cos1.5+sin1.5,
	ptvc=-c(0.2,0.3,0.006,0.05,0,0))
kalcount(reps,pinit=0.01,mu=~sex+cos6+sin6+cos3+sin3+cos1.5+sin1.5+times,
	ptvc=-c(7.36,-1,0.21,0.31,0.006,0.053,0.001,0.034,-0.0023))

kalcount(reps,int="Weibull",psh=1,preg=-9)
kalcount(reps,preg=-c(8,-1.1),ccov=~sex,pinit=0.1,int="Weibull",psh=0.93)
kalcount(reps,preg=-c(7.7,-1),ccov=~sex,pinit=0.04,int="Weibull",psh=1.15,
	tvc=~cos6+sin6,ptvc=-c(0.2,0.3))
kalcount(reps,preg=-c(7.7,-1),ccov=~sex,pinit=0.005,int="Weibull",psh=1,
	tvc=~cos6+sin6+cos3+sin3,ptvc=-c(0.2,0.3,0.005,0.05))
kalcount(reps,preg=-c(7.7,-1),ccov=~sex,pinit=0.005,int="Weibull",psh=1,
	tvc=~cos6+sin6+cos3+sin3+cos1.5+sin1.5,
	ptvc=-c(0.22,0.32,0.005,0.05,0,0.034))
print(zz <- kalcount(reps,pinit=0.01,int="Weibull",psh=1.03,
	mu=~sex+cos6+sin6+cos3+sin3+cos1.5+sin1.5+times,
	ptvc=-c(7.1,-0.96,0.21,0.3,0.006,0.053,0.0037,0.034,-0.0032)))

if(interactive()){
postscript("deaths.eps",height=5)
par(mar=c(3.5,3.5,3,1),mgp=c(2.5,1,0))
plot.iprofile(zz,nind=1:2,xlab="Month",ylab="Deaths",ylim=c(0,3000),
	lty=c(1,1),pch=c(1,3))
dev.off()
}

kalcount(reps,preg=-7.3,pinit=5,dep="serial",update="Markov",pdep=0.026)
kalcount(reps,preg=-c(7.3,-1),ccov=~sex,pinit=5,dep="serial",update="Markov",
	pdep=0.026)
kalcount(reps,preg=-c(7.7,-1),ccov=~sex,pinit=5,dep="serial",update="Markov",
	pdep=0.026,tvc=~cos6+sin6,ptvc=-c(0.3,0.2))
kalcount(reps,preg=-c(7.3,-1),ccov=~sex,pinit=5,dep="serial",update="Markov",
	pdep=0.026,tvc=~cos6+sin6+cos3+sin3,
	ptvc=-c(0.3,0.2,0.005,0.05))
kalcount(reps,preg=-c(7.7,-1),ccov=~sex,pinit=0.01,dep="serial",
	update="Markov",pdep=0.026,tvc=~cos6+sin6+cos3+sin3+cos1.5+sin1.5,
	ptvc=-c(0.22,0.32,0.0045,0.053,0.0023,0.034))
kalcount(reps,pinit=5,dep="serial",update="Markov",
	mu=~sex+cos6+sin6+cos3+sin3+cos1.5+sin1.5+times,
	pdep=0.026,ptvc=-c(7.7,-1,0.21,0.3,0.0058,0.053,0.00077,0.034,-0.003))

kalcount(reps,preg=-8,pinit=0.3,dep="serial",pdep=0.3,
	update="Markov",int="Weibull",psh=1)
kalcount(reps,preg=-c(8,-0.87),ccov=~sex,pinit=0.04,dep="serial",pdep=0.026,
	update="Markov",int="Weibull",psh=1.15)
kalcount(reps,preg=-c(7.7,-1),ccov=~sex,pinit=0.04,dep="serial",pdep=0.026,
	update="Markov",tvc=~cos6+sin6,ptvc=-c(0.2,0.3),int="Weibull",
	psh=1.15)
kalcount(reps,preg=-c(7.7,-1),ccov=~sex,pinit=0.04,dep="serial",pdep=0.016,
	update="Markov",tvc=~cos6+sin6+cos3+sin3,
	ptvc=-c(0.22,0.32,0.005,0.05),int="Weibull",psh=1)
kalcount(reps,preg=-c(7.7,-1),ccov=~sex,pinit=0.01,dep="serial",pdep=0.02,
	update="Markov",tvc=~cos6+sin6+cos3+sin3+cos1.5+sin1.5,
	ptvc=-c(0.22,0.32,0.0045,0.053,0.0023,0.034),
	int="Weibull",psh=1)
kalcount(reps,pinit=0.008,dep="serial",pdep=0.009,update="Markov",
	int="Weibull",psh=1.025,
	mu=~sex+cos6+sin6+cos3+sin3+cos1.5+sin1.5+times,iter=200,
	ptvc=-c(7.13,-0.965,0.21,0.3,0.0058,0.053,0.00077,0.034,-0.003))
