library(repeated)

resp <- read.table("epilepti.dat",skip=6)
colnames(resp) <- c("W2","W4","W6","W8","Treatment","Baseline","Age")
attach(resp)
Base2 <- Baseline^2
Age2 <- Age^2
lag1 <- cbind(Baseline/4,W2,W4,W6)
yy <- restovec(resp[,1:4],times=c(2,4,6,8))

y <- as.vector(t(resp[,1:4]))
y1 <- as.vector(t(lag1))
treatment <- rep(Treatment,rep(4,59))
age <- rep(Age,rep(4,59))
age2 <- age^2
base <- rep(Baseline,rep(4,59))
base2 <- base^2
id <- gl(59,4,236)
times <- gl(4,1,236)

count <- NULL
for(i in 1:59)count <- c(count,cumsum(c(Baseline[i],resp[i,1:3])))

if(interactive()){
postscript("epilepti.eps",height=5)
par(mfrow=c(1,2),font.main=1)
plot(seq(0,8,by=2),c(Baseline[1]/4,W2[1],W4[1],W6[1],W8[1]),type="l",
	ylim=c(0,100),xlab="Week",ylab="Epileptic seizures",main="Placebo")
for(i in 2:28)lines(seq(0,8,by=2),c(Baseline[i]/4,W2[i],W4[i],W6[i],W8[i]))
plot(seq(0,8,by=2),c(Baseline[29]/4,W2[29],W4[29],W6[29],W8[29]),type="l",
	ylim=c(0,100),xlab="Week",ylab="",main="Progabide")
for(i in 30:59)lines(seq(0,8,by=2),c(Baseline[i]/4,W2[i],W4[i],W6[i],W8[i]))
}

zs <- glm(y~id*times,family=poisson)
zs$aic/2
print(summary(z0 <- glm(y~base+base2+age+age2+base:age+treatment*base,
	family=poisson)))
z0$aic/2
print(z1 <- update(z0,.~.+y1))
z1$aic/2
print(z2 <- update(z1,.~.+y1*(base+treatment)))
z2$aic/2
print(z3 <- update(z2,.~.+id))
z3$aic/2
print(z4 <- update(z3,.~.-base:(age+treatment)-age-age2-base2))
z4$aic/2
print(z5 <- update(z3,.~.-y1:(base+treatment)))
z5$aic/2
print(z6 <- update(z3,.~.-y1))
z6$aic/2

print(z7 <- update(z0,.~.+count))
z7$aic/2
print(z8 <- update(z7,.~.+count*(base+treatment)))
z8$aic/2

print(summary(z0a <- glmm(y~base+base2+age+age2+base:age+treatment*base,
	family=poisson,nest=id,points=3)))
z0a$aic/2
rm(z0a)
print(summary(z1a <- glmm(y~base+base2+age+age2+base:age+treatment*base+y1,
	family=poisson,nest=id,points=3)))
z1a$aic/2
rm(z1a)
print(summary(z2a <- glmm(y~base+base2+age+age2+base:age+treatment*base+
	y1*(base+treatment),family=poisson,nest=id,points=3)))
z2a$aic/2

kalcount(yy,pinit=0.001,preg=2,dep="frailty",stepmax=1)
kalcount(yy,ccov=Age,pinit=1,preg=c(-1.7,0.1),dep="frailty")
kalcount(yy,ccov=Treatment,pinit=1,preg=c(-1.7,0),dep="frailty")
kalcount(yy,ccov=Baseline,pinit=3,preg=c(-0.2,0),dep="frailty")
kalcount(yy,ccov=~Baseline+Age,pinit=3,preg=c(-0.2,0,0),dep="frailty")
kalcount(yy,ccov=~Baseline+Age+Treatment,pinit=3,preg=c(-0.2,0,0,0),
	dep="frailty")
kalcount(yy,ccov=~Baseline*Age,pinit=3.7,preg=c(-1,0.008,0.02,-0.0014),
	dep="frailty")
kalcount(yy,ccov=~Baseline*Age,tvcov=lag1,pinit=3.5,
	preg=c(-0.96,0.008,0.029,-0.0014),ptvc=0.002,dep="frailty")

kalcount(yy,ccov=~Baseline+Base2+Age+Age2+
	Baseline:Age+Treatment*Baseline,pinit=3.73,
	preg=c(-0.73,0.004,0.0001,0.021,-0.0001,0,-0.00122,0),dep="frailty")
kalcount(yy,ccov=~Baseline+Base2+Age+Age2+
	Baseline:Age+Treatment*Baseline,pinit=3.7,tvcov=lag1,ptvc=0,
	preg=c(-0.73,0.004,0.0001,0.021,-0.0001,0,-0.00122,0),dep="frailty")

kalcount(yy,intensity="Weibull",ccov=~Baseline*Age,
	pinit=3.7,preg=c(-1,0.008,0.02,-0.0014),psh=1.1,dep="frailty")
kalcount(yy,intensity="log normal",ccov=~Baseline*Age,
	pinit=1.4,preg=c(0.2,-0.002,-0.01,-0.00016),psh=1,dep="frailty")
kalcount(yy,intensity="log logistic",
	ccov=~Baseline*Age,pinit=0.13,preg=c(2,-0.002,-0.01,-0.00014),
	psh=0.171,dep="frailty")
kalcount(yy,intensity="gamma",ccov=~Baseline*Age,
	pinit=3.7,preg=c(-0.733,0.0037,0.02,-0.0012),psh=0.9,dep="frailty")

kalcount(yy,pinit=0.001,preg=-1.4)
kalcount(yy,pinit=0.001,preg=-1.2,dep="serial",update="Markov",pdep=0.5)
kalcount(yy,ccov=~Baseline,pinit=0.001,update="Markov",pdep=0.7,
	preg=c(-1.2,0),dep="serial")
kalcount(yy,ccov=~Baseline+Age,pinit=0.5,
	update="Markov",pdep=0.6,preg=c(-1.2,0,0),dep="serial")
kalcount(yy,ccov=~Baseline+Treatment,pinit=0.5,
	update="Markov",pdep=0.6,preg=c(-1.2,0,0),dep="serial")
kalcount(yy,ccov=~Baseline*Treatment,pinit=0.5,
	update="Markov",pdep=0.6,preg=c(-0.3,0,0,0),dep="serial")
kalcount(yy,ccov=~Baseline+Treatment+Age,pinit=0.5,
	update="Markov",pdep=0.6,preg=c(-1.2,0,0,0),dep="serial")
#kalcount(yy,ccov=~Baseline+Base2+Age+Age2+
#	Baseline:Age+Treatment*Baseline,pinit=0.001,update="Markov",pdep=0.7,
#	preg=c(-1.2,0,0,0,0,0,0,0),dep="serial")

kalcount(yy,ccov=~Baseline+Treatment,pinit=0.5,
	update="count",pdep=0.6,preg=c(-1.2,0,0),dep="serial")
kalcount(yy,ccov=~Baseline+Treatment,pinit=0.5,
	update="event",pdep=0.6,preg=c(-1.2,0,0),dep="serial")
kalcount(yy,ccov=~Baseline+Treatment,pinit=0.5,
	update="serial",pdep=0.6,preg=c(-1.2,0,0),dep="serial")

mu <- function(p) rep(exp(p[1]+p[2]*Baseline+p[3]*Base2+p[4]*Age+p[5]*Age2+
	p[6]*Treatment+p[7]*Baseline*Age+p[8]*Treatment*Baseline),rep(4,59))
gar(yy,dist="Poisson",mu=mu,pdep=0.6,
	preg=c(-0.27,-0.0039,-0.00016,0.11,-0.0022,-0.94,0.0015,0.024))
gar(yy,dist="negative bin",mu=mu,pdep=0.6,psh=1,
	preg=c(-0.27,-0.0039,-0.00016,0.11,-0.0022,-0.94,0.0015,0.024))
mu1 <- function(p) rep(exp(p[1]+p[2]*Baseline+p[3]*Base2+p[4]*Age+
	p[5]*Treatment+p[6]*Baseline*Age+p[7]*Treatment*Baseline),rep(4,59))
gar(yy,dist="negative bin",mu=mu1,pdep=0.6,psh=1,
	preg=c(-0.27,-0.0039,-0.00016,0.11,-0.94,0.0015,0.024))
