library(repeated)
library(gnlm)

data <- read.table("insemin.dat",skip=4,head=T)
attach(data)

N <- as.vector(t(cbind(N1,N2,N3,N4,N5,N6,N7,N8,N9,N10)))
C <- as.vector(t(cbind(C1,C2,C3,C4,C5,C6,C7,C8,C9,C10)))
NC <- N-C
prop <- C/N
bull <- gl(6,10,60)
times <- rep(1:10,6)
pw <- times>1
count1 <- NULL
for(i in 1:6)count1 <- c(count1,cumsum(c(C1[i],C2[i],C3[i],C4[i],C5[i],
	C6[i],C7[i],C8[i],C9[i],C10[i])))
count2 <- NULL
for(i in 1:6)count2 <- c(count2,cumsum(c(N1[i]-C1[i],N2[i]-C2[i],N3[i]-C3[i],
	N4[i]-C4[i],N5[i]-C5[i],N6[i]-C6[i],N7[i]-C7[i],N8[i]-C8[i],
	N9[i]-C9[i],N10[i]-C10[i])))

if(interactive()){
postscript("insemin.eps",height=5,width=5)
plot(1:10,(C/N)[1:10],type="l",ylim=c(0,1),xlab="Sample",
	ylab="Proportion successful")
lines(1:10,(C/N)[11:20])
lines(1:10,(C/N)[21:30])
lines(1:10,(C/N)[31:40])
lines(1:10,(C/N)[41:50])
lines(1:10,(C/N)[51:60])
}

print(zs <- glm(cbind(C[2:60],NC[2:60])~bull[1:59]*times[1:59],family=binomial,
	weights=pw[2:60]))
zs$aic/2
print(z0 <- glm(cbind(C[2:60],NC[2:60])~1,family=binomial,weights=pw[2:60]))
z0$aic/2
print(z1 <- glm(cbind(C[2:60],NC[2:60])~C[1:59]+NC[1:59],family=binomial,
	weights=pw[2:60]))
z1$aic/2
print(z2 <- glm(cbind(C[2:60],NC[2:60])~prop[1:59],family=binomial,
	weights=pw[2:60]))
z2$aic/2
print(z3 <- update(z2,.~.+bull[2:60]))
z3$aic/2
print(z4 <- update(z0,.~.+count1[1:59]+count2[1:59]))
z4$aic/2

mu <- function(p,linear) exp(linear)/(1+exp(linear))
sample <- rep(1:10,6)[2:60]
gnlr(cbind(C[2:60],NC[2:60]),dist="binomial",mu=mu,linear=~prop[1:59],
	pmu=z2$coef,wt=pw[2:60])
gnlr(cbind(C[2:60],NC[2:60]),dist="beta binomial",mu=mu,linear=~1,
	pmu=z0$coef,wt=pw[2:60],psh=3)
gnlr(cbind(C[2:60],NC[2:60]),dist="beta binomial",mu=mu,linear=~prop[1:59],
	pmu=z2$coef,wt=pw[2:60],psh=1)
gnlr(cbind(C[2:60],NC[2:60]),dist="beta binomial",mu=mu,linear=~prop[1:59],
	pmu=z2$coef,wt=pw[2:60],shape=~sample,psh=c(3,0))
shape1 <- function(p,mu) p[1]+log(mu)
gnlr(cbind(C[2:60],NC[2:60]),dist="beta binomial",mu=mu,linear=~prop[1:59],
	pmu=z2$coef,wt=pw[2:60],shape=shape1,psh=3,shfn=T)
shape2 <- function(p,linear,mu) linear+log(mu)
gnlr(cbind(C[2:60],NC[2:60]),dist="beta binomial",mu=mu,
	linear=list(~prop[1:59],~sample),
	pmu=z2$coef,wt=pw[2:60],shape=shape2,psh=c(3.6,0),shfn=T)

y <- cbind(C[2:60],NC[2:60])
prop1 <- prop[1:59]
pw1 <- as.numeric(pw[2:60])
bull1 <- bull[2:60]
count1a <- count1[1:59]
count2a <- count2[1:59]
df <- data.frame(y=I(y),prop1,pw1,bull1,count1a,count2a)
print(z0a <- glmm(y~1,family=binomial,data=df,weights=pw1,nest=bull1))
z0a$aic/2
print(z2a <- glmm(y~prop1,family=binomial,data=df,weights=pw1,nest=bull1))
z2a$aic/2
print(z3a <- glmm(y~count1a+count2a,family=binomial,data=df,weights=pw1,
	nest=bull1))
z3a$aic/2
